@@ -9,7 +9,6 @@
 //  SPDX-License-Identifier: GPL-2.0-or-later WITH LicenseRef-Qt-Commercial-exception-1.0
 
 #include "calendarmanager.h"
-#include "calendarconfig.h"
 
 // Akonadi
 #include "merkuro_calendar_debug.h"
@@ -163,7 +162,7 @@ CalendarManager::CalendarManager(QObject *parent)
 
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
     mCollectionSelectionModelStateSaver = new Akonadi::ETMViewStateSaver(); // not a leak
-    KConfigGroup selectionGroup = config->group("GlobalCollectionSelection");
+    KConfigGroup selectionGroup = config->group(QStringLiteral("GlobalCollectionSelection"));
     mCollectionSelectionModelStateSaver->setView(nullptr);
     mCollectionSelectionModelStateSaver->setSelectionModel(m_calendar->checkableProxyModel()->selectionModel());
     mCollectionSelectionModelStateSaver->restoreState(selectionGroup);
@@ -225,7 +224,7 @@ CalendarManager::CalendarManager(QObject *parent)
     };
     connect(m_flatCollectionTreeModel, &QSortFilterProxyModel::rowsInserted, this, refreshColors);
 
-    KConfigGroup rColorsConfig(config, "Resources Colors");
+    KConfigGroup rColorsConfig(config, QStringLiteral("Resources Colors"));
     m_colorWatcher = KConfigWatcher::create(config);
     connect(m_colorWatcher.data(), &KConfigWatcher::configChanged, this, &CalendarManager::collectionColorsChanged);
 
@@ -242,7 +241,7 @@ void CalendarManager::save()
 {
     Akonadi::ETMViewStateSaver treeStateSaver;
     KSharedConfig::Ptr config = KSharedConfig::openConfig();
-    KConfigGroup group = config->group("GlobalCollectionSelection");
+    KConfigGroup group = config->group(QStringLiteral("GlobalCollectionSelection"));
     treeStateSaver.setView(nullptr);
     treeStateSaver.setSelectionModel(m_calendar->checkableProxyModel()->selectionModel());
     treeStateSaver.saveState(group);
@@ -270,7 +269,7 @@ QAbstractItemModel *CalendarManager::viewCollections()
     return m_viewCollectionModel;
 }
 
-QVector<qint64> CalendarManager::enabledTodoCollections()
+QList<qint64> CalendarManager::enabledTodoCollections()
 {
     return m_enabledTodoCollections;
 }
@@ -411,7 +410,7 @@ void CalendarManager::addIncidence(IncidenceWrapper *incidenceWrapper)
 {
     if (incidenceWrapper->collectionId() < 0) {
         const auto sharedConfig = KSharedConfig::openConfig();
-        const auto editorConfigSection = sharedConfig->group("Editor");
+        const auto editorConfigSection = sharedConfig->group(QStringLiteral("Editor"));
 
         const auto lastUsedCollectionType = incidenceWrapper->incidenceType() == KCalendarCore::IncidenceBase::TypeTodo
             ? QStringLiteral("lastUsedTodoCollection")
@@ -763,3 +762,5 @@ Q_DECLARE_METATYPE(KCalendarCore::Incidence::Ptr)
 #endif
 
 #include "calendarmanager.moc"
+
+#include "moc_calendarmanager.cpp"
