@@ -22,6 +22,7 @@
 #include <QQmlContext>
 #include <QQuickStyle>
 #include <QQuickWindow>
+#include <qobject.h>
 
 static void raiseWindow(QWindow *window)
 {
@@ -31,12 +32,9 @@ static void raiseWindow(QWindow *window)
 
 int main(int argc, char *argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-#endif
     QGuiApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     QApplication app(argc, argv);
-    KLocalizedString::setApplicationDomain("merkuro");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("merkuro"));
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
     QCoreApplication::setApplicationName(QStringLiteral("Merkuro"));
 
@@ -61,7 +59,6 @@ int main(int argc, char *argv[])
         KAboutLicense::GPL_V3,
         // Copyright Statement.
         i18n("(c) KDE Community 2021"));
-    aboutData.setBugAddress("https://bugs.kde.org/enter_bug.cgi?format=guided&product=merkuro&version=" + QStringLiteral(MERKURO_VERSION_STRING).toUtf8());
     aboutData.addAuthor(i18nc("@info:credit", "Carl Schwan"),
                         i18nc("@info:credit", "Maintainer"),
                         QStringLiteral("carl@carlschwan.eu"),
@@ -123,7 +120,7 @@ int main(int argc, char *argv[])
         const auto view = qobject_cast<QQuickWindow *>(obj);
         if (view) {
             KConfig dataResource(QStringLiteral("data"), KConfig::SimpleConfig, QStandardPaths::AppDataLocation);
-            KConfigGroup windowGroup(&dataResource, "Window");
+            KConfigGroup windowGroup(&dataResource, QStringLiteral("Window"));
             KWindowConfig::restoreWindowSize(view, windowGroup);
             KWindowConfig::restoreWindowPosition(view, windowGroup);
 
