@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2023 Carl Schwan <carl@carlschwan.eu>
 // SPDX-License-Identifier: LGPL-2.1-or-later
-
+#pragma once
 #include <abstractapplication.h>
 
 class MailApplication : public AbstractApplication
@@ -10,7 +10,7 @@ class MailApplication : public AbstractApplication
 public:
     explicit MailApplication(QObject *parent = nullptr);
 
-    QVector<KActionCollection *> actionCollections() const override;
+    QList<KActionCollection *> actionCollections() const override;
 
 Q_SIGNALS:
     void createNewMail();
