@@ -2,6 +2,7 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 
 #include "../config-merkuro.h"
+#include "messagehandler.h"
 #include <KAboutData>
 #include <KDBusService>
 #include <KLocalizedContext>
@@ -9,6 +10,7 @@
 #include <KWindowSystem>
 #include <QApplication>
 #include <QCommandLineParser>
+#include <QDir>
 #include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
@@ -23,12 +25,9 @@ static void raiseWindow(QWindow *window)
 
 int main(int argc, char *argv[])
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QGuiApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-#endif
     QGuiApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     QApplication app(argc, argv);
-    KLocalizedString::setApplicationDomain("merkuro");
+    KLocalizedString::setApplicationDomain(QByteArrayLiteral("merkuro"));
     QCoreApplication::setOrganizationName(QStringLiteral("KDE"));
     QCoreApplication::setApplicationName(QStringLiteral("Merkuro Mail"));
 
@@ -53,7 +52,6 @@ int main(int argc, char *argv[])
         KAboutLicense::GPL_V3,
         // Copyright Statement.
         i18n("(c) KDE Community 2021"));
-    aboutData.setBugAddress("https://bugs.kde.org/enter_bug.cgi?format=guided&product=merkuro&version=" + QStringLiteral(MERKURO_VERSION_STRING).toUtf8());
     aboutData.addAuthor(i18nc("@info:credit", "Carl Schwan"),
                         i18nc("@info:credit", "Maintainer"),
                         QStringLiteral("carl@carlschwan.eu"),
@@ -72,24 +70,48 @@ int main(int argc, char *argv[])
 
     KDBusService service(KDBusService::Unique);
 
+    const auto options = parser.optionNames();
+    const auto args = parser.positionalArguments();
     QQmlApplicationEngine engine;
     engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-    engine.load(QUrl(QStringLiteral("qrc:/qml/app/main.qml")));
-
-    QObject::connect(&service, &KDBusService::activateRequested, &engine, [&engine](const QStringList & /*arguments*/, const QString & /*workingDirectory*/) {
+    if (args.length() > 0) {
+        qmlRegisterType<MessageHandler>("org.kde.merkuro.mail.desktop", 1, 0, "MessageHandler");
+        QObject::connect(&engine, &QQmlApplicationEngine::quit, &app, &QCoreApplication::quit);
+        engine.load(QUrl(QStringLiteral("qrc:/qml/desktopactions/openmbox.qml")));
         const auto rootObjects = engine.rootObjects();
+        if (rootObjects.isEmpty()) {
+            return -1;
+        }
+        parser.process(app);
+
+        const QStringList args = parser.positionalArguments();
         for (auto obj : rootObjects) {
             auto view = qobject_cast<QQuickWindow *>(obj);
-            if (view) {
-                raiseWindow(view);
-                return;
-            }
+            auto messageHandler = view->findChild<MessageHandler *>(QStringLiteral("MessageHandler"));
+            const auto file = QUrl::fromUserInput(args.at(args.count() - 1), QDir::currentPath());
+            messageHandler->open(file);
         }
-    });
+    } else {
+        engine.load(QUrl(QStringLiteral("qrc:/qml/app/main.qml")));
+
+        QObject::connect(&service,
+                         &KDBusService::activateRequested,
+                         &engine,
+                         [&engine](const QStringList & /*arguments*/, const QString & /*workingDirectory*/) {
+                             const auto rootObjects = engine.rootObjects();
+                             for (auto obj : rootObjects) {
+                                 auto view = qobject_cast<QQuickWindow *>(obj);
+                                 if (view) {
+                                     raiseWindow(view);
+                                     return;
+                                 }
+                             }
+                         });
+    }
 
     if (engine.rootObjects().isEmpty()) {
         return -1;
     }
 
     return app.exec();
-}
\ No newline at end of file
+}
